@@ -1,8 +1,10 @@
 package IRC::Message::Object;
-$IRC::Message::Object::VERSION = '0.092001';
+$IRC::Message::Object::VERSION = '0.092002';
 use strictures 2;
 use Carp;
 
+use Scalar::Util 'blessed';
+
 use List::Objects::WithUtils;
 use List::Objects::Types -all;
 use Types::Standard -all;
@@ -38,7 +40,11 @@ has filter => (
 );
 
 sub __build_filter {
-  POE::Filter::IRCv3->new( colonify => (defined $_[1] ? $_[1] : 0) )
+  POE::Filter::IRCv3->new(
+    colonify => (
+      defined $_[1] ? $_[1] : $_[0]->colonify
+    ),
+  )
 }
 
 
@@ -64,8 +70,8 @@ has raw_line => (
   predicate => 1,
   default   => sub {
     my ($self) = @_;
-    my %opts;
-    for (qw/prefix command params tags/) {
+    my %opts = ( command => $self->command );
+    for (qw/colonify prefix params tags/) {
       my $pred = "has_".$_;
       $opts{$_} = $self->$_ if $self->$pred;
     }
@@ -90,7 +96,9 @@ sub BUILDARGS {
     if (defined $params{raw_line}) {
       ## Try to create self from raw_line instead:
       my $filt = $params{filter} ?
-        $params{filter} : $class->__build_filter($params{colonify});
+        $params{filter} : $class->__build_filter(
+          defined $params{colonify} ? $params{colonify} : 0
+        );
       my $refs = $filt->get( [$params{raw_line}] );
       %params = %{ $refs->[0] } if @$refs;
     } else {
@@ -168,7 +176,7 @@ sub truncate {
     $new = length $current <= 510 ? $current : substr $current, 0, 510 ;
   }
 
-  (ref $self)->new(raw_line => $new)
+  (blessed $self)->new(raw_line => $new)
 }
 
 sub TO_JSON {
@@ -204,8 +212,7 @@ IRC::Message::Object - Incoming or outgoing IRC events
     params   => [ 'user', 'Welcome to IRC' ],
   );
 
-  ## ... or import and use the 'ircmsg()' shortcut:
-  use IRC::Message::Object 'ircmsg';
+  ## ... or use the 'ircmsg()' shortcut:
   my $event = ircmsg(
     command => '001',
     prefix  => ':some.server.org',
